@@ -10,7 +10,7 @@ def __get_task(__system_args: SystemArgs,default:str="create"):
         default,
     )
 
-def parse_input(__system_args: SystemArgs = None):
+def process_pypitk(__system_args: SystemArgs = None):
     system_args = SystemArgs.init() if __system_args is None else __system_args
     task = __get_task(system_args)
     if task == "create":
